==> jc-1.4.0.tar.gz: java/nio/charset/UnmappableCharacterException.h <==
// public class java.nio.charset.UnmappableCharacterException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c9c34a3e4ea2cab5 java_nio_charset_CharacterCodingException
// @dep_class d32daafc4753a389 java_nio_charset_UnmappableCharacterException

// header file dependencies
// @dep_header java_nio_charset_CharacterCodingException

#include "java/nio/charset/CharacterCodingException.h"

#ifndef _JC_java_nio_charset_UnmappableCharacterException_H_
#define _JC_java_nio_charset_UnmappableCharacterException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_nio_charset_UnmappableCharacterException$sub_refs	_jc_java_nio_charset_UnmappableCharacterException$sub_refs;
typedef struct _jc_java_nio_charset_UnmappableCharacterException$sub_nonrefs	_jc_java_nio_charset_UnmappableCharacterException$sub_nonrefs;
typedef struct _jc_java_nio_charset_UnmappableCharacterException$refs	_jc_java_nio_charset_UnmappableCharacterException$refs;
typedef struct _jc_java_nio_charset_UnmappableCharacterException$nonrefs	_jc_java_nio_charset_UnmappableCharacterException$nonrefs;
typedef struct _jc_java_nio_charset_UnmappableCharacterException$object	_jc_java_nio_charset_UnmappableCharacterException$object;

typedef const struct _jc_java_nio_charset_UnmappableCharacterException$vmethods	_jc_java_nio_charset_UnmappableCharacterException$vmethods;
typedef const struct _jc_java_nio_charset_UnmappableCharacterException$vtable	_jc_java_nio_charset_UnmappableCharacterException$vtable;
typedef const struct _jc_java_nio_charset_UnmappableCharacterException$vtype	_jc_java_nio_charset_UnmappableCharacterException$vtype;

// Constructors
extern void _jc_java_nio_charset_UnmappableCharacterException$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_nio_charset_UnmappableCharacterException$object *, jint);

// Virtual methods
extern jint _jc_java_nio_charset_UnmappableCharacterException$method$getInputLength$471df90fb92db657(_jc_env *, struct _jc_java_nio_charset_UnmappableCharacterException$object *);
extern struct _jc_java_lang_String$object *_jc_java_nio_charset_UnmappableCharacterException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_java_nio_charset_UnmappableCharacterException$object *);

// Virtual method descriptors
extern _jc_method _jc_java_nio_charset_UnmappableCharacterException$method_info$getInputLength$471df90fb92db657;
extern _jc_method _jc_java_nio_charset_UnmappableCharacterException$method_info$getMessage$13aaf240efc902b1;

// Virtual methods structure
struct _jc_java_nio_charset_UnmappableCharacterException$vmethods {
	jint	(*getInputLength$471df90fb92db657)(_jc_env *, struct _jc_java_nio_charset_UnmappableCharacterException$object *);
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_java_nio_charset_UnmappableCharacterException$object *);
};

// Vtable
struct _jc_java_nio_charset_UnmappableCharacterException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_nio_charset_CharacterCodingException$vmethods	java_nio_charset_CharacterCodingException;
	_jc_java_nio_charset_UnmappableCharacterException$vmethods	java_nio_charset_UnmappableCharacterException;
};

// Vtype
struct _jc_java_nio_charset_UnmappableCharacterException$vtype {
	_jc_type			type;
	_jc_java_nio_charset_UnmappableCharacterException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_charset_UnmappableCharacterException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_charset_UnmappableCharacterException$refs {
    _jc_java_nio_charset_UnmappableCharacterException$sub_refs	java_nio_charset_UnmappableCharacterException;
    _jc_java_nio_charset_CharacterCodingException$sub_refs	java_nio_charset_CharacterCodingException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_charset_UnmappableCharacterException$sub_nonrefs {
	jint	inputLength;
};

// Non-reference instance fields (object)
struct _jc_java_nio_charset_UnmappableCharacterException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_nio_charset_CharacterCodingException$sub_nonrefs	java_nio_charset_CharacterCodingException;
    _jc_java_nio_charset_UnmappableCharacterException$sub_nonrefs	java_nio_charset_UnmappableCharacterException;
};

// Object instance structure
struct _jc_java_nio_charset_UnmappableCharacterException$object {
	_jc_java_nio_charset_UnmappableCharacterException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_charset_UnmappableCharacterException$vtype	*vtype;
	_jc_java_nio_charset_UnmappableCharacterException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_charset_UnmappableCharacterException$vtype _jc_java_nio_charset_UnmappableCharacterException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_charset_UnmappableCharacterException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_charset_UnmappableCharacterException$class_object;

#endif	/* _JC_java_nio_charset_UnmappableCharacterException_H_ */

==> jc-1.4.6.tar.gz: java/nio/charset/UnmappableCharacterException.h <==
// public class java.nio.charset.UnmappableCharacterException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c9c34a3e4ea2cab5 java_nio_charset_CharacterCodingException
// @dep_class d32daafc4753a389 java_nio_charset_UnmappableCharacterException

// header file dependencies
// @dep_header java_nio_charset_CharacterCodingException

#include "java/nio/charset/CharacterCodingException.h"

#ifndef _JC_java_nio_charset_UnmappableCharacterException_H_
#define _JC_java_nio_charset_UnmappableCharacterException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_nio_charset_UnmappableCharacterException$sub_refs	_jc_java_nio_charset_UnmappableCharacterException$sub_refs;
typedef struct _jc_java_nio_charset_UnmappableCharacterException$sub_nonrefs	_jc_java_nio_charset_UnmappableCharacterException$sub_nonrefs;
typedef struct _jc_java_nio_charset_UnmappableCharacterException$refs	_jc_java_nio_charset_UnmappableCharacterException$refs;
typedef struct _jc_java_nio_charset_UnmappableCharacterException$nonrefs	_jc_java_nio_charset_UnmappableCharacterException$nonrefs;
typedef struct _jc_java_nio_charset_UnmappableCharacterException$object	_jc_java_nio_charset_UnmappableCharacterException$object;

typedef const struct _jc_java_nio_charset_UnmappableCharacterException$vmethods	_jc_java_nio_charset_UnmappableCharacterException$vmethods;
typedef const struct _jc_java_nio_charset_UnmappableCharacterException$vtable	_jc_java_nio_charset_UnmappableCharacterException$vtable;
typedef const struct _jc_java_nio_charset_UnmappableCharacterException$vtype	_jc_java_nio_charset_UnmappableCharacterException$vtype;

// Constructors
extern void _jc_java_nio_charset_UnmappableCharacterException$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_nio_charset_UnmappableCharacterException$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_nio_charset_UnmappableCharacterException$method$getInputLength$471df90fb92db657(_jc_env *, struct _jc_java_nio_charset_UnmappableCharacterException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_nio_charset_UnmappableCharacterException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_java_nio_charset_UnmappableCharacterException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_nio_charset_UnmappableCharacterException$method_info$getInputLength$471df90fb92db657;
extern _jc_method _jc_java_nio_charset_UnmappableCharacterException$method_info$getMessage$13aaf240efc902b1;

// Virtual methods structure
struct _jc_java_nio_charset_UnmappableCharacterException$vmethods {
	jint	(*getInputLength$471df90fb92db657)(_jc_env *, struct _jc_java_nio_charset_UnmappableCharacterException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_java_nio_charset_UnmappableCharacterException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_nio_charset_UnmappableCharacterException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_nio_charset_CharacterCodingException$vmethods	java_nio_charset_CharacterCodingException;
	_jc_java_nio_charset_UnmappableCharacterException$vmethods	java_nio_charset_UnmappableCharacterException;
};

// Vtype
struct _jc_java_nio_charset_UnmappableCharacterException$vtype {
	_jc_type			type;
	_jc_java_nio_charset_UnmappableCharacterException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_charset_UnmappableCharacterException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_charset_UnmappableCharacterException$refs {
    _jc_java_nio_charset_UnmappableCharacterException$sub_refs	java_nio_charset_UnmappableCharacterException;
    _jc_java_nio_charset_CharacterCodingException$sub_refs	java_nio_charset_CharacterCodingException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_charset_UnmappableCharacterException$sub_nonrefs {
	jint	inputLength;
};

// Non-reference instance fields (object)
struct _jc_java_nio_charset_UnmappableCharacterException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_nio_charset_CharacterCodingException$sub_nonrefs	java_nio_charset_CharacterCodingException;
    _jc_java_nio_charset_UnmappableCharacterException$sub_nonrefs	java_nio_charset_UnmappableCharacterException;
};

// Object instance structure
struct _jc_java_nio_charset_UnmappableCharacterException$object {
	_jc_java_nio_charset_UnmappableCharacterException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_charset_UnmappableCharacterException$vtype	*vtype;
	_jc_java_nio_charset_UnmappableCharacterException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_charset_UnmappableCharacterException$vtype _jc_java_nio_charset_UnmappableCharacterException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_charset_UnmappableCharacterException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_charset_UnmappableCharacterException$class_object;

#endif	/* _JC_java_nio_charset_UnmappableCharacterException_H_ */
